@@ -1,9 +1,9 @@
 package App::MusicExpo;
-use v5.14;
+use 5.014000;
 use strict;
 use warnings;
 
-our $VERSION = '0.006';
+our $VERSION = '1.000';
 
 use Audio::FLAC::Header qw//;
 use HTML::Template::Compiled qw//;
@@ -29,9 +29,9 @@ our $cache='';
 our $template='';
 
 GetOptions (
-	"template:s" => \$template,
-	"prefix:s" => \$prefix,
-	"cache:s" => \$cache,
+	'template:s' => \$template,
+	'prefix:s' => \$prefix,
+	'cache:s' => \$cache,
 );
 
 sub flacinfo{
@@ -54,7 +54,7 @@ sub flacinfo{
 sub mp3info{
 	my $file=$_[0];
 	my %tag = map { encode 'UTF-8', $_ } %{get_mp3tag $file};
-	my @trkn = split '/', $tag{TRACKNUM} // '';
+	my @trkn = split m#/#s, $tag{TRACKNUM} // '';
 
 	freeze +{
 		format => 'MP3',
@@ -86,7 +86,7 @@ sub vorbisinfo{
 	}
 }
 
-sub mp4_format ($){
+sub mp4_format ($){ ## no critic (ProhibitSubroutinePrototypes)
 	my $encoding = $_[0];
 	return 'AAC' if $encoding eq 'mp4a';
 	return 'ALAC' if $encoding eq 'alac';
@@ -128,9 +128,8 @@ sub normalizer{
 sub make_fragment{ join '-', map { lc =~ y/a-z0-9/_/csr } @_ }
 
 sub run {
-	my %info = %info;
 	if ($cache) {
-		tie my %cache, 'DB_File', $cache, O_RDWR|O_CREAT, 0644;
+		tie my %cache, 'DB_File', $cache, O_RDWR|O_CREAT, 0644; ## no critic (ProhibitTie)
 		$info{$_} = memoize $info{$_}, INSTALL => undef, NORMALIZER => \&normalizer, LIST_CACHE => 'FAULT', SCALAR_CACHE => [HASH => \%cache] for keys %info;
 	}
 
@@ -164,7 +163,7 @@ sub run {
 
 	@files = sort { $a->{title} cmp $b->{title} } @files;
 	$ht->param(files => \@files, prefix => $prefix);
-	print $ht->output;
+	print $ht->output; ## no critic (RequireCheckedSyscalls)
 }
 
 $default_template = <<'HTML';
@@ -238,7 +237,7 @@ Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2013-2015 by Marius Gavrilescu
+Copyright (C) 2013-2016 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.14.2 or,
